@@ -13,7 +13,9 @@ function d3_geo_conicConformal(φ0, φ1) {
   if (!n) return d3_geo_mercator;
 
   function forward(λ, φ) {
-    var ρ = abs(abs(φ) - halfπ) < ε ? 0 : F / Math.pow(t(φ), n);
+    if (F > 0) { if (φ < -halfπ + ε) φ = -halfπ + ε; }
+    else { if (φ > halfπ - ε) φ = halfπ - ε; }
+    var ρ = F / Math.pow(t(φ), n);
     return [
       ρ * Math.sin(n * λ),
       F - ρ * Math.cos(n * λ)
